# Execute Commands

Commands are executed with the `just` command runner (https://github.com/casey/just)

There are two just files, which contain commands:
- `Evaluation/Justfile` contains commands, which run on all projects. To run a recipe, execute `cd Evaluation; just command`
- `Evaluation/project/Justfile` contains commands, which run on a single project. To run a recipe, execute `cd Evaluation/projects/$PROJECT; just --dotenv-path .env command`

In each Justfile, there are the following commands:
- `coverage_seed`: Record coverage of seed corpus
- `coverage_fuzzing`: Record coverage after fuzzing without seed corpus, but dictionary.
- `coverage_fuzzing_seed`: Record coverage after fuzzing with seed corpus and dictionary.
- `dynamic_callgraph_fuzzing_seed`: Record a dynamic call graph for a corpus created by fuzzing and an initial seed corpus.
- `static_callgraphs`: Compute static call graphs for all analysis frameworks and all call graph algorithms

Some commands can be adjusted with the following options, which can be set on the commandline with `just OPTION=val command`.
- `FUZZING_THREADS := "8"`: Number of threads the fuzzer is executed with
- `FUZZING_TIME := "3600"`: Number of seconds to run the fuzzer
- `DYNCG_TIMEOUT := "999m"`: Timeout for computing the dynamic call graphs
- `DYNCG_MEMORY := "400G"`: Memory for computing the dynamic call graphs
- `STATICCG_TIMEOUT := "90m"`: Timeout for computing the static call graphs
- `STATICCG_MEMORY := "400G"`: Memory to computing the static call graphs

The result of a command is stored in directory `projects/$PROJECT/target`:
- Recipes `coverage_seed`, `coverage_fuzzing`, `coverage_fuzzing_seed`, and `dynamic_callgraph_fuzzing_seed`  store their result in `projects/$PROJECT/target/$EXPERIMENT`, where `EXPERIMENT` is the suffix of the recipe name.
- Recipe `static_callgraphs` stores its result in `projects/$PROJECT/target/staticcg/$PROJECT/$FRAMEWORK/$ALGO`.

# Create a fuzzer for a new project

To create a new fuzzer follow the steps below:
1. Copy from another project, e.g. `cp -r projects/axion projects/newproject`
2. Set the project name, path within the java corpus, fuzzing corpus, and intrumented classes in `projects/newproject/run_fuzzer.sh`.
3. Create a fuzzer `projects/newproject/src/NewprojectFuzzer.java` (https://github.com/CodeIntelligenceTesting/jazzer/tree/main/examples/src/main/java/com/example). 
   The name of the fuzzer must be the project name with a capital first letter followed by `Fuzzer.java`.