FROM maven:3.8.5-openjdk-8

# Clone xcorpus repository
RUN git clone https://bitbucket.org/jensdietrich/xcorpus/ /xcorpus-src

# Setup ant
RUN mkdir -p /xcorpus-src/ant && \
    unzip -q /xcorpus-src/misc/docker/ant.zip -d /xcorpus-src/ant
ENV ANT_HOME=/xcorpus-src/ant/apache-ant-1.10.1
ENV PATH=${PATH}:${ANT_HOME}/bin

# Install build utilities
RUN apt update && apt -y install zip

# Download missing dependencies
ARG AXION_PATH=/xcorpus-src/data/qualitas_corpus_20130901/axion-1.0-M2/project
RUN mvn dependency:copy -Dartifact=axion:axion:1.0-M2-dev -DoutputDirectory=${AXION_PATH} && \
    mv ${AXION_PATH}/axion-1.0-M2-dev.jar ${AXION_PATH}/bin.zip && \
    mvn dependency:copy -Dartifact=axion:axion:1.0-M2-dev:pom -DoutputDirectory=${AXION_PATH} && \
    mvn dependency:copy-dependencies -f ${AXION_PATH}/axion-1.0-M2-dev.pom -DoutputDirectory=${AXION_PATH}/default-lib/

ARG BATIK_PATH=/xcorpus-src/data/qualitas_corpus_20130901/batik-1.7/project
RUN wget https://repo1.maven.org/maven2/xmlbeans/xbean/2.2.0/xbean-2.2.0.jar -P${BATIK_PATH}/default-lib/
RUN --mount=type=bind,source=batik/,target=/xcorpus-src/data/qualitas_corpus_20130901/batik-1.7/project/patch/ \
    for JAR in $(ls ${BATIK_PATH}/patch); \
    do  \
      zip -d ${BATIK_PATH}/default-lib/${JAR} META-INF/MANIFEST.MF; \
      jar -uvfm ${BATIK_PATH}/default-lib/${JAR} ${BATIK_PATH}/patch/${JAR}/META-INF/MANIFEST.MF;  \
    done

ARG XERCES_PATH=/xcorpus-src/data/qualitas_corpus_20130901/xerces-2.10.0/project
RUN unzip -q ${XERCES_PATH}/bin.zip -d ${XERCES_PATH}/jar/ && \
    rm -rf ${XERCES_PATH}/jar/xercesSamples && \
    mv ${XERCES_PATH}/jar/xercesImpl/* ${XERCES_PATH}/jar/ && \
    rmdir ${XERCES_PATH}/jar/xercesImpl/ && \
    jar cf ${XERCES_PATH}/bin.zip -C ${XERCES_PATH}/jar/ .

# Ensure project/default-lib directories are present
RUN find /xcorpus-src/data -name 'project' -type d -exec mkdir -p {}/default-lib \;

# Setup xcorpus
RUN cd /xcorpus-src/tools && \
    ant release && \
    unzip -q /xcorpus-src/xcorpus-1.0.0.zip -d /xcorpus

# Clean up
# RUN rm -rf /xcorpus-src

WORKDIR /xcorpus